@@ -213,7 +213,7 @@ def preprocessing_preleads(df,industry_dictionary,state_dictionary,mx_bv_diction
     df_preleads_clean=devutils.impute_nas(df=df_preleads_clean,columns_to_impute=impute_columns,imp=imputer)
 
     #Impute growth columns
-
+    df=devutils.impute_growth(df=df,impute_growth_flag=impute_growth_flag)
     # Log transformation
     cols_to_transform= ["QEmployeesOnLinkedIn","CompanyFollowers","LeadFollowers"]
     df_preleads_clean=devutils.log_transformation(df_preleads_clean,columns=cols_to_transform)
@@ -233,6 +233,10 @@ def preprocessing_preleads(df,industry_dictionary,state_dictionary,mx_bv_diction
     df_preleads_clean = utils.reduce_mem_usage_category(df_preleads_clean)
     df_preleads_clean = utils.one_hot_encoding(df=df_preleads_clean)
 
+    logging.info( f"NA after ONH:" )
+    logging.info( f"{df_preleads_clean.columns}" )
     _, df_preleads_clean = sample.align(df_preleads_clean,join='left',axis=1)
     
+    logging.info( f"NA after aligning:" )
+    logging.info( f"{df_preleads_clean.columns}" )
     return df_preleads_clean
